function xNew=filterX(SysData,SysDataNew,x,busFtr,swFtr,pvFtr,pqFtr,shuntFtr,lineFtr,indFtr,zipFtr,synFtr,excFtr,tgFtr)
% Filter system states using the filters generated by filterSysData()
%
% FUNCTION filterX
%
% Author: Rui Yao <ruiyao@ieee.org>
%
% Copyright (C) 2021, UChicago Argonne, LLC. All rights reserved.
%
% OPEN SOURCE LICENSE
% 
% Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
% 
% 1. Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
% 2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
% 3. Neither the name of the copyright holder nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.
% 
% 
% ******************************************************************************************************
% DISCLAIMER
% 
% THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED
% WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
% PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY 
% DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, 
% PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
% CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR 
% OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
% ***************************************************************************************************
% 
% INPUT
%	SysData - Current system data
%	SysDataNew - New filtered system data
%	x - Current system states
%	*Ftr - Filter of current data to rip off inactive components
%
% OUTPUT
%	xNew - Filtered system states
%

[V,Q,s,d,w,eq1,eq2,ed1,ed2,psid,psiq,Pm,Ef,Vavrm,Vavrr,Vavrf,Vavrref,tgovg,tgovm,tgovmech,f,dpg,qplt,vg]=unfoldX(x,SysData);

V=V(busFtr,:);
Q=Q(busFtr,:);
s=s(indFtr,:);
d=d(synFtr,:);
w=w(synFtr,:);
eq1=eq1(synFtr,:);
eq2=eq2(synFtr,:);
ed1=ed1(synFtr,:);
ed2=ed2(synFtr,:);
psid=psid(synFtr,:);
psiq=psiq(synFtr,:);
Pm=Pm(synFtr,:);
Ef=Ef(synFtr,:);
Vavrm=Vavrm(excFtr,:);
Vavrr=Vavrr(excFtr,:);
Vavrf=Vavrf(excFtr,:);
Vavrref=Vavrref(excFtr,:);
tgovg=tgovg(tgFtr,:);
tgovm=tgovm(tgFtr,:);
tgovmech=tgovmech(tgFtr,:);
f=f(busFtr,:);
dpg=dpg(busFtr,:);

xNew=foldX(SysDataNew,V,Q,s,d,w,eq1,eq2,ed1,ed2,psid,psiq,Pm,Ef,Vavrm,Vavrr,Vavrf,Vavrref,tgovg,tgovm,tgovmech,f,dpg,qplt,vg);
end